Function

Enum Function 

pub enum Function {
Show 90 variants Opposite, Not, Plus, Minus, Multiply, Divide, Modulo, StringConcat, Gt, Lt, GtEq, LtEq, Eq, NotEq, And, Or, Xor, BitwiseOr, BitwiseAnd, BitwiseXor, Exp, Ln, Log, Abs, Sin, Cos, Sqrt, Pow, Case, Concat(usize), CharLength, Lower, Upper, Md5, Position, Random(usize), Pi, CastAsText, CastAsFloat, CastAsInteger, CastAsBoolean, CastAsDateTime, CastAsDate, CastAsTime, Least, Greatest, Rtrim, Ltrim, Substr, SubstrWithSize, Ceil, Floor, Round, Trunc, RegexpContains, RegexpExtract, RegexpReplace, Newid, Encode, Decode, Unhex, CurrentDate, CurrentTime, CurrentTimestamp, ExtractEpoch, ExtractYear, ExtractMonth, ExtractDay, ExtractHour, ExtractMinute, ExtractSecond, ExtractMicrosecond, ExtractMillisecond, ExtractDow, ExtractWeek, Dayname, FromUnixtime, UnixTimestamp, DateFormat, Quarter, DatetimeDiff, Date, InList, Coalesce, Sign, Like, Ilike, Choose, IsNull, IsBool,
}
The list of operators inspired by: https://docs.rs/sqlparser/latest/sqlparser/ast/enum.BinaryOperator.html and mostly: https://docs.rs/polars/latest/polars/prelude/enum.Operator.html

Variants



Opposite



Not



Plus



Minus



Multiply



Divide



Modulo



StringConcat



Gt



Lt



GtEq



LtEq



Eq



NotEq



And



Or



Xor



BitwiseOr



BitwiseAnd



BitwiseXor



Exp



Ln



Log



Abs



Sin



Cos



Sqrt



Pow



Case



Concat(usize)



CharLength



Lower



Upper



Md5



Position



Random(usize)



Pi



CastAsText



CastAsFloat



CastAsInteger



CastAsBoolean



CastAsDateTime



CastAsDate



CastAsTime



Least



Greatest



Rtrim



Ltrim



Substr



SubstrWithSize



Ceil



Floor



Round



Trunc



RegexpContains



RegexpExtract



RegexpReplace



Newid



Encode



Decode



Unhex



CurrentDate



CurrentTime



CurrentTimestamp



ExtractEpoch



ExtractYear



ExtractMonth



ExtractDay



ExtractHour



ExtractMinute



ExtractSecond



ExtractMicrosecond



ExtractMillisecond



ExtractDow



ExtractWeek



Dayname



FromUnixtime



UnixTimestamp



DateFormat



Quarter



DatetimeDiff



Date



InList



Coalesce



Sign



Like



Ilike



Choose



IsNull



IsBool

Implementations

Source

impl Function

pub fn style(self) -> Style

Return the style of display

pub fn arity(self) -> Arity

Return the arity of the function

pub fn is_bijection(self) -> bool

Return true if it is bijective

pub fn is_unique(self) -> bool

Return true if it implicitly depends on the row index and is unique

pub fn super_image(self, sets: &[DataType]) -> Result<DataType>

Return the function object implementing the function

pub fn value(self, args: &[Value]) -> Result<Value>

Return the function object implementing the function